rm -f /usr/share/icons/hicolor/icon-theme.cache
export GCONF_CONFIG_SOURCE="xml:merged:/etc/gconf/gconf.xml.defaults"
/usr/bin/gconftool-2 --makefile-install-rule /etc/gconf/schemas/alarm-clock.schemas > /dev/null 2>&1

